==> skypager-collection-5.0.2.tgz: package/src/collection/index.spec.js <==
import Collection from '.'
import { join } from 'path'

describe('Skypager Document Collection', function() {
  it('defines scopes', function() {
    const docsCollection = new Collection({
      base: join(process.cwd(), 'test', 'fixtures')
    })

    docsCollection.scope('testcases', /^testcases/)

    docsCollection.scope('testcases').should.be.an('object')
  })

  it('has an instance id', function() {
    const docsCollection = new Collection({
      type: 'documents',
      base: join(process.cwd(), 'test', 'fixtures', 'testcases') ,
    })

    docsCollection.should.have.property('instanceId')
    docsCollection.should.have.property('pathId')
  })

  it('has a type', function() {
    const docsCollection = new Collection({
      type: 'documents',
      base: join(process.cwd(), 'test', 'fixtures', 'testcases') ,
    })

    docsCollection.should.have.property('type', 'document')
  })

  it('has a path router', function() {
    const docsCollection = new Collection({
      type: 'documents',
      base: join(process.cwd(), 'test', 'fixtures', 'testcases') ,
    })

    docsCollection.should.have.property('router')
  })

  it('has an importer with some files', function() {
    const docsCollection = new Collection({
      type: 'documents',
      base: join(process.cwd(), 'test', 'fixtures', 'testcases') ,
    })

    docsCollection.should.have.property('importer').that.is.an('object')
    docsCollection.should.have.property('files').that.is.an('array')
  })

  it('loads files', function(done) {
    const docsCollection = new Collection({
      type: 'documents',
      base: join(process.cwd(), 'test', 'fixtures', 'testcases') ,
    })

    docsCollection.ready.then((importer) => {
      importer.files.should.not.be.empty
      done()
    })
  })

  it('specifies patterns based on the type of collection', function() {
    const docsCollection = new Collection({
      type: 'documents',
      base: join(process.cwd(), 'test', 'fixtures', 'testcases') ,
    })

    docsCollection.patterns.should.include('**/*.md')
  })
})

==> skypager-collection-5.5.0.tgz: package/src/collection/index.spec.js <==
import Collection from '.'
import { join } from 'path'

describe('Skypager Document Collection', function() {
  it('defines scopes', function() {
    const docsCollection = new Collection({
      context: join(process.cwd(), 'test', 'fixtures')
    })

    docsCollection.scope('testcases', /^testcases/)

    docsCollection.scope('testcases').should.be.an('object')
  })

  it('has an instance id', function() {
    const docsCollection = new Collection({
      type: 'documents',
      context: join(process.cwd(), 'test', 'fixtures', 'testcases') ,
    })

    docsCollection.should.have.property('instanceId')
    docsCollection.should.have.property('pathId')
  })

  it('has a type', function() {
    const docsCollection = new Collection({
      type: 'documents',
      context: join(process.cwd(), 'test', 'fixtures', 'testcases') ,
    })

    docsCollection.should.have.property('type', 'document')
  })

  it('has a path router', function() {
    const docsCollection = new Collection({
      type: 'documents',
      context: join(process.cwd(), 'test', 'fixtures', 'testcases') ,
    })

    docsCollection.should.have.property('router')
  })

  it('has an importer with some files', function() {
    const docsCollection = new Collection({
      type: 'documents',
      context: join(process.cwd(), 'test', 'fixtures', 'testcases') ,
    })

    docsCollection.should.have.property('importer').that.is.an('object')
    docsCollection.should.have.property('files').that.is.an('array')
  })

  it('loads files', function(done) {
    const docsCollection = new Collection({
      type: 'documents',
      context: join(process.cwd(), 'test', 'fixtures', 'testcases') ,
    })

    docsCollection.ready.then((importer) => {
      importer.files.should.not.be.empty
      done()
    })
  })

  it('specifies patterns contextd on the type of collection', function() {
    const docsCollection = new Collection({
      type: 'documents',
      context: join(process.cwd(), 'test', 'fixtures', 'testcases') ,
    })

    docsCollection.patterns.should.include('**/*.md')
  })
})
